﻿using System;
using System.Windows.Controls;

namespace RIASilverlightApplication
{
    public partial class MainPage : UserControl
    {
        bool _isDeleting = false;
        public MainPage()
        {
            InitializeComponent();
        }

        #region RIADomain_LoadedData
        private void RIADomain_LoadedData(object sender,
            LoadedDataEventArgs e)
        {
            if (e.HasError)
            {
                System.Windows.MessageBox.Show(e.Error.ToString(), "Load Error",
                    System.Windows.MessageBoxButton.OK);
                e.MarkErrorAsHandled();
            }
        }
        #endregion

        #region TasksDataGrid_RowEditEnded
        private void TasksDataGrid_RowEditEnded(object sender,
            DataGridRowEditEndedEventArgs e)
        {
            // Updates the datasource if there have been any changes
            if (RIADomainDatasource.HasChanges)
            {
                RIADomainDatasource.SubmitChanges();
            }
        }
        #endregion

        #region TasksDataForm_EditEnded
        private void TasksDataForm_EditEnded(object sender,
            DataFormEditEndedEventArgs e)
        {
            // Updates the datasource if there have been any changes
            if (RIADomainDatasource.HasChanges)
            {
                RIADomainDatasource.SubmitChanges();
            }
        }
        #endregion

        #region TasksDataForm_CurrentItemChanged
        private void TasksDataForm_CurrentItemChanged(object sender, EventArgs e)
        {
            // Only try to update if in deleting mode
            if (_isDeleting)
            {
                // Updates the datasource if there have been any changes
                if (RIADomainDatasource.HasChanges)
                {
                    RIADomainDatasource.SubmitChanges();
                }
                _isDeleting = false;
            }
        }
        #endregion

        #region TasksDataForm_DeletingItem
        private void TasksDataForm_DeletingItem(object sender,
            System.ComponentModel.CancelEventArgs e)
        {
            // Mark _isDeleting as True so it can be 
            // handled in TasksDataForm_CurrentItemChanged
            _isDeleting = true;
        }
        #endregion
    }
}